@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertDistImage;
 
 our $DATE = '2016-07-13'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -20,6 +20,7 @@ has include_files => (is => 'rw');
 has exclude_files => (is => 'rw');
 has include_file_pattern => (is => 'rw');
 has exclude_file_pattern => (is => 'rw');
+has check_exists => (is => 'rw', default=>sub{0});
 
 sub mvp_multivalue_args { qw(include_files exclude_files) }
 
@@ -72,7 +73,7 @@ sub munge_files {
     my $code_insert = sub {
         my ($path) = @_;
         $path =~ s!\\!/!g; # WIN
-        unless (-f $path) {
+        unless (!$self->check_exists || (-f $path)) {
             $self->log_fatal(["File %s does not exist", $path]);
         }
         unless ($path =~ /\.(jpe?g|png|gif)\z/) {
@@ -176,7 +177,7 @@ Dist::Zilla::Plugin::InsertDistImage - Insert images contained in distribution i
 
 =head1 VERSION
 
-This document describes version 0.002 of Dist::Zilla::Plugin::InsertDistImage (from Perl distribution Dist-Zilla-Plugin-InsertDistImage), released on 2016-07-13.
+This document describes version 0.003 of Dist::Zilla::Plugin::InsertDistImage (from Perl distribution Dist-Zilla-Plugin-InsertDistImage), released on 2016-07-13.
 
 =head1 SYNOPSIS
 
@@ -282,6 +283,10 @@ C<data:> URIs where the image data is directly embedded in the URL.
 
 =head2 exclude_file_pattern => re
 
+=head2 check_exists => bool (default: 0)
+
+Set to 1 to check that the file exists.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-InsertDistImage>.
